@@ -365,10 +365,10 @@ impl PyPTY {
     }
 }
 
-#[pymodule]
+#[pymodule(gil_used = false)]
 fn winpty(py: Python<'_>, m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add("__version__", VERSION)?;
-    m.add("WinptyError", py.get_type_bound::<WinptyError>())?;
+    m.add("WinptyError", py.get_type::<WinptyError>())?;
     m.add_class::<PyPTY>()?;
     Ok(())
 }
